#!/usr/local/bin/python

import sys

from federation import topdl
from federation.remote_service import service_caller
from federation.client_lib import client_opts, exit_with_fault, RPCException,\
	wrangle_standard_options, do_rpc, get_experiment_names, info_format

class ftopo_opts(client_opts):
    def __init__(self):
        client_opts.__init__(self)
        self.add_option("--experiment_cert", dest="exp_certfile",
                type="string", help="experiment certificate file")
        self.add_option("--experiment_name", dest="exp_name",
                type="string", help="human readable experiment name")

parser = ftopo_opts()
(opts, args) = parser.parse_args()
try:
    cert, fid = wrangle_standard_options(opts)
except RuntimeError, e:
    sys.exit("%s" % e)

if opts.exp_name and opts.exp_certfile:
    sys.exit("Only one of --experiment_cert and --experiment_name permitted")
elif opts.exp_certfile:
    exp_id = { 'fedid': fedid(file=opts.exp_certfile) }
elif opts.exp_name:
    exp_id = { 'localname' : opts.exp_name }
else:
    sys.exit("specify one of --experiment_cert and --experiment_name")

req = { 'experiment': exp_id }

try:
    resp_dict = do_rpc(req,
	    opts.url, opts.transport, cert, opts.trusted, 
	    serialize_only=opts.serialize_only,
	    tracefile=opts.tracefile,
	    caller=service_caller('Info'), responseBody='InfoResponseBody')
except RPCException, e:
    exit_with_fault(e)
except RuntimeError, e:
    sys.exit("Error processing RPC: %s" % e)

if 'experimentdescription' in resp_dict and \
	'topdldescription' in resp_dict['experimentdescription']:
    top = \
	topdl.Topology(\
	**resp_dict['experimentdescription']['topdldescription'])

    for e in [ e for e in top.elements \
	    if isinstance(e, topdl.Computer)]:
	hn = e.get_attribute('hostname')
	tb = e.get_attribute('testbed')
	if hn and tb:
	    print ":".join([",".join(e.name), hn, tb])
else:
    sys.exit("Badly formatted response!?")
