#!/usr/local/bin/python

import sys

from federation.remote_service import service_caller
from federation.client_lib import client_opts, exit_with_fault, RPCException,\
	wrangle_standard_options, do_rpc, get_experiment_names, info_format

class exp_data_opts(client_opts):
    def __init__(self):
        client_opts.__init__(self)
        self.add_option("--experiment_cert", dest="exp_certfile",
                type="string", help="experiment certificate file")
        self.add_option("--experiment_name", dest="exp_name",
                type="string", help="human readable experiment name")
        self.add_option("--data", dest="data", default=[],
                action="append", type="choice",
                choices=("id", "experimentdescription", "federant", "vtopo", 
		    "vis", "log", "status"),
                help="data to extract")
        
parser = exp_data_opts()
(opts, args) = parser.parse_args()
cert, fid = wrangle_standard_options(opts)

if opts.exp_name and opts.exp_certfile:
    sys.exit("Only one of --experiment_cert and --experiment_name permitted")
elif opts.exp_certfile:
    exp_id = { 'fedid': fedid(file=opts.exp_certfile) }
elif opts.exp_name:
    exp_id = { 'localname' : opts.exp_name }
else:
    sys.exit("specify one of --experiment_cert and --experiment_name")

req = { 'experiment': exp_id }

try:
    resp_dict = do_rpc(req,
	    opts.url, opts.transport, cert, opts.trusted, 
	    serialize_only=opts.serialize_only,
	    tracefile=opts.tracefile,
	    caller=service_caller('Info'), responseBody='InfoResponseBody')
except RPCException, e:
    exit_with_fault(e)
except RuntimeError, e:
    sys.exit("Error processing RPC: %s" % e)

formatter = info_format()
for d in opts.data:
    formatter(resp_dict, d)
